==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","ǰe");
define("_URL","}");
define("_PRINTER","͵CL榡");
define("_FRIEND","HB");



define("_YOURNAME","zWr");

define("_OK","Tw");
define("_RELATED","쵲");
define("_MOREABOUT","h");
define("_NEWSBY","sDӷ");
define("_MOSTREAD","̨w諸ɡA");
define("_READMORE","ԲӤe...");
define("_BYTESMORE","줸");
define("_COMMENTSQ","ѷNH");
define("_COMMENT","N");

define("_CONFIGURE","]w");
define("_LOGINCREATE","nJ/ͷsb");
define("_THRESHOLD","e");
define("_NOCOMMENTS","ܷN");
define("_NESTED","_");
define("_FLAT","Z");
define("_THREAD","u");
define("_OLDEST","ª");
define("_NEWEST","s");
define("_HIGHEST","");
define("_COMMENTSWARNING","ۧ@vݩ@̡A鷺etd");
define("_SCORE","ơG");


define("_USERINFO","ϥΪ̸T");
define("_READREST","\תl...");
define("_REPLY","^");
define("_REPLYMAIN","o");
define("_NOSUBJECT","LD");
define("_NOANONCOMMENTS","\ΦWo, Х <a href=\"modules.php?name=Your_Account\">U</a>");
define("_PARENT","_");
define("_ROOT","");

define("_UCOMMENT","");
define("_ALLOWEDHTML","\HTMLykG");
define("_POSTANON","ΦWo");
define("_EXTRANS","Extrans (html tags to )");
define("_HTMLFORMATED","HTML榡");
define("_PLAINTEXT","@r榡");
define("_ONN","...");
define("_SUBJECT","D");
define("_COMMENTREPLY","No");
define("_COMREPLYPRE","Now");
define("_NOTRIGHT","ƥܼơITȨѰѦ");
define("_SENDAMSG","HXT");
define("_YOUSENDSTORY","zNHX");
define("_TOAFRIEND","̡G");
define("_FYOURNAME","zmWG");
define("_FYOUREMAIL","z E-mailG");
define("_FFRIENDNAME","zBͪmWG");
define("_FFRIENDEMAIL","zBͪ E-mailG");
define("_INTERESTING","P쪺峹b");
define("_HELLO","");
define("_YOURFRIEND","zB");
define("_CONSIDERED","ıoog峹AMz@P");
define("_FDATE","G");
define("_FTOPIC","sDDDG");
define("_YOUCANREAD","ШӦ\Ūog쪺峹");
define("_FSTORY","");
define("_HASSENT","wQHX");
define("_THANKS","¡I");
define("_RECOMMEND","˥B");
define("_PDATE","G");
define("_PTOPIC","sDDDG");
define("_COMESFROM","峹Ӧ۩");
define("_THEURL","oɪ}OG");





define("_PREVIEW","w");
define("_NEWUSER","sϥΪ");
define("_OPTIONS","ﶵ");


define("_REFRESH","sz");
define("_ADD","sW");
define("_NOCOMMENTSACT","藍_, ثeog峹LkܷN.");
define("_ARTICLEPOLL","媺벼");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","ǰe");
define("_URL","}");
define("_PRINTER","͵CL榡");
define("_FRIEND","HB");



define("_YOURNAME","zWr");

define("_OK","Tw");
define("_RELATED","쵲");
define("_MOREABOUT","h");
define("_NEWSBY","sDӷ");
define("_MOSTREAD","̨w諸ɡA");
define("_READMORE","ԲӤe...");
define("_BYTESMORE","줸");
define("_COMMENTSQ","ѷNH");
define("_COMMENT","N");

define("_CONFIGURE","]w");
define("_LOGINCREATE","nJ/ͷsb");
define("_THRESHOLD","e");
define("_NOCOMMENTS","ܷN");
define("_NESTED","_");
define("_FLAT","Z");
define("_THREAD","u");
define("_OLDEST","ª");
define("_NEWEST","s");
define("_HIGHEST","");
define("_COMMENTSWARNING","ۧ@vݩ@̡A鷺etd");
define("_SCORE","ơG");


define("_USERINFO","ϥΪ̸T");
define("_READREST","\תl...");
define("_REPLY","^");
define("_REPLYMAIN","o");
define("_NOSUBJECT","LD");
define("_NOANONCOMMENTS","\ΦWo, Х <a href=\"modules.php?name=Your_Account\">U</a>");
define("_PARENT","_");
define("_ROOT","");

define("_UCOMMENT","");
define("_ALLOWEDHTML","\HTMLykG");
define("_POSTANON","ΦWo");
define("_EXTRANS","Extrans (html tags to )");
define("_HTMLFORMATED","HTML榡");
define("_PLAINTEXT","@r榡");
define("_ONN","...");
define("_SUBJECT","D");
define("_COMMENTREPLY","No");
define("_COMREPLYPRE","Now");
define("_NOTRIGHT","ƥܼơITȨѰѦ");
define("_SENDAMSG","HXT");
define("_YOUSENDSTORY","zNHX");
define("_TOAFRIEND","̡G");
define("_FYOURNAME","zmWG");
define("_FYOUREMAIL","z E-mailG");
define("_FFRIENDNAME","zBͪmWG");
define("_FFRIENDEMAIL","zBͪ E-mailG");
define("_INTERESTING","P쪺峹b");
define("_HELLO","");
define("_YOURFRIEND","zB");
define("_CONSIDERED","ıoog峹AMz@P");
define("_FDATE","G");
define("_FTOPIC","sDDDG");
define("_YOUCANREAD","ШӦ\Ūog쪺峹");
define("_FSTORY","");
define("_HASSENT","wQHX");
define("_THANKS","¡I");
define("_RECOMMEND","˥B");
define("_PDATE","G");
define("_PTOPIC","sDDDG");
define("_COMESFROM","峹Ӧ۩");
define("_THEURL","oɪ}OG");





define("_PREVIEW","w");
define("_NEWUSER","sϥΪ");
define("_OPTIONS","ﶵ");


define("_REFRESH","sz");
define("_ADD","sW");
define("_NOCOMMENTSACT","藍_, ثeog峹LkܷN.");
define("_ARTICLEPOLL","媺벼");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
